@@ -1,10 +1,9 @@
-use super::errors::FxError;
 use super::layout::Split;
 use serde::{Deserialize, Serialize};
 use std::fs::read_to_string;
 use std::path::Path;
 
-pub const SESSION_FILE: &str = ".session";
+#[allow(dead_code)]
 pub const SESSION_EXAMPLE: &str = "sort_by = \"Name\"
 show_hidden = false
 preview = false
@@ -25,27 +24,22 @@ pub enum SortKey {
     Time,
 }
 
-pub fn read_session(session_path: &Path) -> Result<Session, FxError> {
+pub fn read_session(session_path: &Path) -> Session {
     match read_to_string(session_path) {
         Ok(s) => match serde_yaml::from_str(&s) {
-            Ok(de) => Ok(de),
-            Err(_) => Ok(Session {
+            Ok(de) => de,
+            Err(_) => Session {
                 sort_by: SortKey::Name,
                 show_hidden: true,
                 preview: Some(false),
                 split: Some(Split::Vertical),
-            }),
+            },
         },
-        Err(_) => Ok(Session {
+        Err(_) => Session {
             sort_by: SortKey::Name,
             show_hidden: true,
             preview: Some(false),
             split: Some(Split::Vertical),
-        }),
+        },
     }
 }
-
-pub fn make_session(session_file: &Path) -> Result<(), FxError> {
-    std::fs::write(session_file, SESSION_EXAMPLE)?;
-    Ok(())
-}
